@@ -48,26 +48,9 @@ source "${BASH_SOURCE%/*}/../unix/InstallFromCompressedFileFromURL.sh"
 # shellcheck source=../unix/SetEnvVar.sh
 source "${BASH_SOURCE%/*}/../unix/SetEnvVar.sh"
 
-function SourceEnvVar {
-    echo "Source environment variables file"
-    if [ uname -a | grep -q "Ubuntu" ];
-    then
-        if [ lsb_release -a | grep "Ubuntu 22.04" ];
-        then source ~/.bashrc
-        else source ~/.profile
-        fi
-    else
-        source ~/.bashrc
-        source ~/.zshrc
-    fi
-}
-
-
 version="n6.0"
 url_public="https://github.com/FFmpeg/FFmpeg/archive/refs/tags/$version.tar.gz"
 sha1="78435ec71cc2227017a99c030e858719b8c7c74d"
-
-
 url_cached="http://ci-files01-hki.intra.qt.io/input/ffmpeg/$version.tar.gz"
 ffmpeg_name="FFmpeg-$version"
 
@@ -82,6 +65,24 @@ fi
 
 ffmpeg_config_options=$(cat "${BASH_SOURCE%/*}/../shared/ffmpeg_config_options.txt")
 
+install_ff_nvcodec_headers() {
+  nv_codec_version="11.1" # use 11.1 to ensure compatibility with 470 nvidia drivers; might be upated to 12.0
+  nv_codec_url_public="https://github.com/FFmpeg/nv-codec-headers/archive/refs/heads/sdk/$nv_codec_version.zip"
+  nv_codec_url_cached="http://ci-files01-hki.ci.qt.io/input/ffmpeg/nv-codec-headers/nv-codec-headers-sdk-$nv_codec_version.zip"
+  nv_codec_sha1="ceb4966ab01b2e41f02074675a8ac5b331bf603e"
+  #nv_codec_sha1="4f30539f8dd31945da4c3da32e66022f9ca59c08" // 12.0
+  nv_codec_dir="$target_dir/nv-codec-headers-sdk-$nv_codec_version"
+  if [ ! -d  "$nv_codec_dir" ];
+  then
+    InstallFromCompressedFileFromURL "$nv_codec_url_cached" "$nv_codec_url_public" "$nv_codec_sha1" "$target_dir" ""
+  fi
+
+  sudo make -C "$nv_codec_dir" install -j
+
+  # Might be not detected by default on RHEL
+  export PKG_CONFIG_PATH="$PKG_CONFIG_PATH:/usr/local/lib/pkgconfig"
+}
+
 
 build_ffmpeg() {
   local arch="$1"
@@ -94,8 +95,7 @@ build_ffmpeg() {
   then prefix="/usr/local/$ffmpeg_name"
   fi
 
-  # android configures its own toolchain, it does not use the system clang
-  if [ -n "$arch" ] && [ "$os" != "android" ]
+  if [ -n "$arch" ]
   then cc="clang -arch $arch"
   fi
 
@@ -107,37 +107,10 @@ build_ffmpeg() {
   popd
 }
 
-build_ffmpeg_android() {
-  SourceEnvVar
-  target_arch=$1
-  target_dir=$2
-
-  if [ "$target_arch" == "x86_64" ];
-  then
-    #emulador on CI is x86_64
-    target_toolchain_arch="x86_64-linux-android"
-    target_arch=x86_64
-    target_cpu=x86_64
-  else
-    #emulador on CI is x86
-    target_toolchain_arch="i686-linux-android"
-    target_arch=x86
-    target_cpu=i686
-  fi
-
-  api_version=24
-
-  toolchain=${ANDROID_NDK_ROOT_DEFAULT}/toolchains/llvm/prebuilt/${ANDROID_NDK_HOST}
-  toolchain_bin=${toolchain}/bin
-  sysroot=${toolchain}/sysroot
-  cxx=${toolchain_bin}/${target_toolchain_arch}${api_version}-clang++
-  cc=${toolchain_bin}/${target_toolchain_arch}${api_version}-clang
-
-  ffmpeg_config_options+=" --disable-vulkan --target-os=android --enable-jni --enable-mediacodec --enable-pthreads --enable-neon --disable-asm --cpu=${target_cpu} --disable-indev=android_camera --sysroot=${sysroot} --sysinclude=${sysroot}/usr/include/ --cc=${cc} --cxx=${cxx}"
-  build_ffmpeg ${target_arch} ${target_dir}
-}
-
 if [ "$os" == "linux" ]; then
+  install_ff_nvcodec_headers
+
+  ffmpeg_config_options+=" --enable-openssl"
   build_ffmpeg
   sudo mv "$ffmpeg_source_dir/build/installed/usr/local/$ffmpeg_name" "/usr/local"
   SetEnvVar "FFMPEG_DIR" "/usr/local/$ffmpeg_name"
@@ -158,39 +131,5 @@ elif [ "$os" == "macos-universal" ]; then
   sudo "${BASH_SOURCE%/*}/../macos/makeuniversal.sh" "$ffmpeg_source_dir/build/arm64/installed" "$ffmpeg_source_dir/build/x86_64/installed"
   SetEnvVar "FFMPEG_DIR" "/usr/local/$ffmpeg_name"
 
-elif  [ "$os" == "android" ]; then
-
-  SourceEnvVar
-
-  url_cached=""
-  url_public=""
-  sha1=""
-
-  #get emulator target arch
-  if [ "$ANDROID_EMULATOR" == *"x86_64"* ];
-  then
-    target_arch=x86_64
-    sha1="0241fd483c16f4ce53206b911214b06854cdef9d"
-    url_cached="http://ci-files01-hki.intra.qt.io/input/ffmpeg/android-ffmpeg-x86_64.zip"
-    target_dir="/opt/android/$ffmpeg_name/ffmpeg-x86_64"
-  else
-    target_arch=x86
-    url_cached="http://ci-files01-hki.intra.qt.io/input/ffmpeg/android-ffmpeg-x86.zip"
-    sha1="8b254e31411a350edb581bb30e31401866abbe7d"
-    target_dir="/opt/android/$ffmpeg_name/ffmpeg-x86"
-  fi
-
-  app_prefix=""
-
-  #try install a pre-build
-  InstallFromCompressedFileFromURL "$url_cached" "$url_public" "$sha1" "$target_dir" "$app_prefix"
-
-  #if could not install pre-build, build it
-  if [ ! -d "$target_dir" ];
-  then build_ffmpeg_android "$target_arch" "$target_dir"
-  fi
-
-  #set the var to use in yaml
-  SetEnvVar "FFMPEG_DIR_ANDROID" "$target_dir"
 fi
 
